/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "pokerdiscussion.h"

void pokerDiscussionGet(
  pokerdiscussion_t *discussion, pokerdiscussiondata_t *data
) {
  discussion->count = 0;
  memset(discussion->players, 0xFF,
    sizeof(uint8_t) * POKER_DISCUSSION_MESSAGE_COUNT_MAX
  );

  switch(data->reason) {
    // Match Start Conversations
    case POKER_DISCUSSION_REASON_MATCH_START:
      discussion->count++;
      discussion->messages[0] = "Match Start";
      discussion->players[0] = POKER_DEALER_INDEX;
      discussion->emotions[0] = VN_CHARACTER_EMOTION_BORED;
      break;
    
    // Round Start Conversations
    case POKER_DISCUSSION_REASON_ROUND_START:
      discussion->count++;
      discussion->messages[0] = "Round Start";
      discussion->players[0] = POKER_DEALER_INDEX;
      discussion->emotions[0] = VN_CHARACTER_EMOTION_BORED;
      break;
    
    // Round Start Conversations
    case POKER_DISCUSSION_REASON_BLINDS_TAKEN:
      discussion->count++;
      discussion->messages[0] = "Blinds have been taken.";
      discussion->players[0] = POKER_DEALER_INDEX;
      discussion->emotions[0] = VN_CHARACTER_EMOTION_BORED;
      break;
    
    // Betting conversations
    case POKER_DISCUSSION_REASON_PLAYER_FOLDING:
      discussion->count++;
      discussion->messages[0] = "I fold.";
      discussion->players[0] = data->playerCause;
      discussion->emotions[0] = VN_CHARACTER_EMOTION_ANGRY;
      break;
    
    case POKER_DISCUSSION_REASON_PLAYER_CHECKING:
      discussion->count++;
      discussion->messages[0] = "I check.";
      discussion->players[0] = data->playerCause;
      discussion->emotions[0] = VN_CHARACTER_EMOTION_ANGRY;
      break;

    case POKER_DISCUSSION_REASON_PLAYER_CALLING:
      discussion->count++;
      discussion->messages[0] = "I call.";
      discussion->players[0] = data->playerCause;
      discussion->emotions[0] = VN_CHARACTER_EMOTION_SMUG;
      break;
    
    case POKER_DISCUSSION_REASON_PLAYER_RAISING:
      discussion->count++;
      discussion->messages[0] = "I raise.";
      discussion->players[0] = data->playerCause;
      discussion->emotions[0] = VN_CHARACTER_EMOTION_BOASTFUL;
      break;

    // Fallback
    default:
      discussion->count++;
      discussion->messages[0] = "Hmm, this seems to be an error message.";
      discussion->players[0] = POKER_DEALER_INDEX;
      discussion->emotions[0] = VN_CHARACTER_EMOTION_CONCERNED_WORRIED;
      break;
  }
}

void pokerDiscussionQueue(pokerdiscussiondata_t *data) {
  pokerdiscussion_t discussion;
  uint8_t i, player;

  pokerDiscussionGet(&discussion, data);

  for(i = 0; i < discussion.count; i++) {
    player = discussion.players[i];
    
    pokerGameActionLookAdd(data->poker, player);
    vnConversationTalk(&data->poker->scene.conversation,
      discussion.messages[i],
      data->poker->scene.characters + player,
      discussion.emotions[i]
    );
  }
}